==> customtkinterx-0.1.2.tar.gz: customtkinterx-0.1.2/customtkinterx/CTkFluentTheme.py <==
fluent_json = """
{
  "CTk": {
    "fg_color": ["#ffffff", "#101010"]
  },
  "CTkToplevel": {
    "fg_color": ["#ffffff", "#101010"]
  },
  "CTkFrame": {
    "corner_radius": 8,
    "border_width": 1,
    "fg_color": ["#ffffff", "#1c1c1c"],
    "top_fg_color": ["#ffffff", "#2c2c2c"],
    "border_color": ["#b0b2b2", "#424556"]
  },
  "CTkButton": {
    "corner_radius": 6,
    "border_width": 0,
    "fg_color": ["#0067c0", "#4cc2ff"],
    "hover_color": ["#1975c5", "#48b2e9"],
    "border_color": ["#f3f3f3", "#949A9F"],
    "text_color": ["#ffffff", "#000000"],
    "text_color_disabled": ["gray74", "gray60"]
  },
  "CTkLabel": {
    "corner_radius": 0,
    "fg_color": "transparent",
    "text_color": ["gray10", "#DCE4EE"]
  },
  "CTkEntry": {
    "corner_radius": 6,
    "border_width": 1,
    "fg_color": ["#F9F9FA", "#343638"],
    "border_color": ["#f2f2f2", "#303030"],
    "text_color":["#000000", "#ffffff"],
    "placeholder_text_color": ["gray52", "gray62"]
  },
  "CTkCheckbox": {
    "corner_radius": 6,
    "border_width": 3,
    "fg_color": ["#3B8ED0", "#1F6AA5"],
    "border_color": ["#3E454A", "#949A9F"],
    "hover_color": ["#3B8ED0", "#1F6AA5"],
    "checkmark_color": ["#DCE4EE", "gray90"],
    "text_color": ["gray10", "#DCE4EE"],
    "text_color_disabled": ["gray60", "gray45"]
  },
  "CTkSwitch": {
    "corner_radius": 1000,
    "border_width": 0,
    "button_length": 0,
    "fg_color": ["#939BA2", "#4A4D50"],
    "progress_color": ["#0067c0", "#4cc2ff"],
    "button_color": ["gray36", "#D5D9DE"],
    "button_hover_color": ["gray20", "gray100"],
    "text_color": ["gray10", "#DCE4EE"],
    "text_color_disabled": ["gray60", "gray45"]
  },
  "CTkRadiobutton": {
    "corner_radius": 1000,
    "border_width_checked": 6,
    "border_width_unchecked": 3,
    "fg_color": ["#3B8ED0", "#1F6AA5"],
    "border_color": ["#3E454A", "#949A9F"],
    "hover_color": ["#36719F", "#144870"],
    "text_color": ["gray10", "#DCE4EE"],
    "text_color_disabled": ["gray60", "gray45"]
  },
  "CTkProgressBar": {
    "corner_radius": 1000,
    "border_width": 0,
    "fg_color": ["#939BA2", "#4A4D50"],
    "progress_color": ["#3B8ED0", "#1F6AA5"],
    "border_color": ["gray", "gray"]
  },
  "CTkSlider": {
    "corner_radius": 1000,
    "button_corner_radius": 1000,
    "border_width": 6,
    "button_length": 0,
    "fg_color": ["#939BA2", "#4A4D50"],
    "progress_color": ["gray40", "#AAB0B5"],
    "button_color": ["#3B8ED0", "#1F6AA5"],
    "button_hover_color": ["#36719F", "#144870"]
  },
  "CTkOptionMenu": {
    "corner_radius": 6,
    "fg_color": ["#3B8ED0", "#1F6AA5"],
    "button_color": ["#36719F", "#144870"],
    "button_hover_color": ["#27577D", "#203A4F"],
    "text_color": ["#DCE4EE", "#DCE4EE"],
    "text_color_disabled": ["gray74", "gray60"]
  },
  "CTkComboBox": {
    "corner_radius": 6,
    "border_width": 1,
    "fg_color": ["#F9F9FA", "#343638"],
    "border_color": ["#f2f2f2", "#303030"],
    "button_color": ["#f2f2f2", "#565B5E"],
    "button_hover_color": ["#f2f2f2", "#565B5E"],
    "text_color": ["gray10", "#ffffff"],
    "text_color_disabled": ["gray50", "gray45"]
  },
  "CTkScrollbar": {
    "corner_radius": 1000,
    "border_spacing": 4,
    "fg_color": "transparent",
    "button_color": ["gray55", "gray41"],
    "button_hover_color": ["gray40", "gray53"]
  },
  "CTkSegmentedButton": {
    "corner_radius": 6,
    "border_width": 2,
    "fg_color": ["#979DA2", "gray29"],
    "selected_color": ["#3B8ED0", "#1F6AA5"],
    "selected_hover_color": ["#36719F", "#144870"],
    "unselected_color": ["#979DA2", "gray29"],
    "unselected_hover_color": ["gray70", "gray41"],
    "text_color": ["#DCE4EE", "#DCE4EE"],
    "text_color_disabled": ["gray74", "gray60"]
  },
  "CTkTextbox": {
    "corner_radius": 6,
    "border_width": 0,
    "fg_color": ["#F9F9FA", "#1D1E1E"],
    "border_color": ["#979DA2", "#565B5E"],
    "text_color":["gray10", "#DCE4EE"],
    "scrollbar_button_color": ["gray55", "gray41"],
    "scrollbar_button_hover_color": ["gray40", "gray53"]
  },
  "CTkScrollableFrame": {
    "label_fg_color": ["gray78", "gray23"]
  },
  "DropdownMenu": {
    "fg_color": ["gray90", "gray20"],
    "hover_color": ["gray75", "gray28"],
    "text_color": ["gray10", "gray90"]
  },
  "CTkFont": {
    "macOS": {
      "family": "SF Display",
      "size": 13,
      "weight": "normal"
    },
    "Windows": {
      "family": "Roboto",
      "size": 13,
      "weight": "normal"
    },
    "Linux": {
      "family": "Roboto",
      "size": 13,
      "weight": "normal"
    }
  }
}
"""


import os.path


fluent_path = os.path.abspath(os.path.dirname(__file__)).replace("\\", "/") + "/Fluent.json"


def fluent_theme():
    from tempfile import mkstemp
    from customtkinter import set_default_color_theme
    _, __temp = mkstemp(suffix=".json")
    with open(__temp, "w") as __temp_file:
        __temp_file.write(fluent_json)
    return __temp


def use_fluent_theme():
    from customtkinter import set_default_color_theme
    try:
        set_default_color_theme(fluent_path)
    except FileNotFoundError:
        set_default_color_theme(fluent_theme())

==> customtkinterx-0.3.1.tar.gz: customtkinterx-0.3.1/customtkinterx/CTkFluentTheme.py <==
fluent_json = """
{
  "CTkCustom": {
    "titlebar_color": ["#ffffff", "#2c2c2c"],
    "title_color": ["gray10", "#DCE4EE"],

    "transparent_color": "#101010",

    "closebutton_text_color": ["#000000", "#ffffff"],
    "closebutton_color": ["#ffffff", "#2c2c2c"],
    "closebutton_hover_color": ["#b40d1b", "#b40d1b"],

    "minimizebutton_text_color": ["#000000", "#ffffff"],
    "minimizebutton_color": ["#ffffff", "#2c2c2c"],
    "minimizebutton_hover_color": ["#cccccc", "#282828"]
  },
  "CTkInfoBar": {
    "corner_radius": 8,
    "border_width": 0,

    "fg_color": ["#f7f7f7", "#2f2f2f"],
    "fg_hover_color": ["#c3c3c3", "#555555"],

    "border_color": ["#b0b2b2", "#424556"],

    "success_color": ["#dff6dd", "#393d1b"],
    "success_hover_color": ["#b0c3af", "#5c632b"],
    "caution_color": ["#fff4ce", "#433519"],
    "caution_hover_color": ["#ccc3a4", "#695327"],
    "critical_color": ["#fde7e9", "#442726"],
    "critical_hover_color": ["#cab8ba", "#6a3c3b"]

  },
  "CTk": {
    "fg_color": ["#ffffff", "#101010"]
  },
  "CTkToplevel": {
    "fg_color": ["#ffffff", "#101010"]
  },
  "CTkFrame": {
    "corner_radius": 8,
    "border_width": 1,
    "fg_color": ["#ffffff", "#1c1c1c"],
    "top_fg_color": ["#ffffff", "#2c2c2c"],
    "border_color": ["#b0b2b2", "#424556"]
  },
  "CTkButton": {
    "corner_radius": 6,
    "border_width": 0,
    "fg_color": ["#0067c0", "#4cc2ff"],
    "hover_color": ["#1975c5", "#48b2e9"],
    "border_color": ["#f3f3f3", "#949A9F"],
    "text_color": ["#ffffff", "#000000"],
    "text_color_disabled": ["gray74", "gray60"]
  },
  "CTkLabel": {
    "corner_radius": 0,
    "fg_color": "transparent",
    "text_color": ["gray10", "#DCE4EE"]
  },
  "CTkEntry": {
    "corner_radius": 6,
    "border_width": 1,
    "fg_color": ["#F9F9FA", "#343638"],
    "border_color": ["#f2f2f2", "#303030"],
    "text_color":["#000000", "#ffffff"],
    "placeholder_text_color": ["gray52", "gray62"]
  },
  "CTkCheckbox": {
    "corner_radius": 6,
    "border_width": 3,
    "fg_color": ["#3B8ED0", "#1F6AA5"],
    "border_color": ["#3E454A", "#949A9F"],
    "hover_color": ["#3B8ED0", "#1F6AA5"],
    "checkmark_color": ["#DCE4EE", "gray90"],
    "text_color": ["gray10", "#DCE4EE"],
    "text_color_disabled": ["gray60", "gray45"]
  },
  "CTkSwitch": {
    "corner_radius": 1000,
    "border_width": 0.1,
    "button_length": 0,
    "fg_color": ["#ededed", "#1d1d1d"],
    "progress_color": ["#0067c0", "#4cc2ff"],
    "button_color": ["#f3f3f3", "#000000"],
    "button_hover_color": ["#bfbfbf", "#050505"],
    "text_color": ["gray10", "#DCE4EE"],
    "text_color_disabled": ["gray60", "gray45"]
  },
  "CTkRadiobutton": {
    "corner_radius": 1000,
    "border_width_checked": 6,
    "border_width_unchecked": 3,
    "fg_color": ["#3B8ED0", "#1F6AA5"],
    "border_color": ["#3E454A", "#949A9F"],
    "hover_color": ["#36719F", "#144870"],
    "text_color": ["gray10", "#DCE4EE"],
    "text_color_disabled": ["gray60", "gray45"]
  },
  "CTkProgressBar": {
    "corner_radius": 1000,
    "border_width": 0,
    "fg_color": ["#939BA2", "#4A4D50"],
    "progress_color": ["#3B8ED0", "#1F6AA5"],
    "border_color": ["gray", "gray"]
  },
  "CTkSlider": {
    "corner_radius": 1000,
    "button_corner_radius": 1000,
    "border_width": 6,
    "button_length": 0,
    "fg_color": ["#939BA2", "#4A4D50"],
    "progress_color": ["gray40", "#AAB0B5"],
    "button_color": ["#3B8ED0", "#1F6AA5"],
    "button_hover_color": ["#36719F", "#144870"]
  },
  "CTkOptionMenu": {
    "corner_radius": 6,
    "fg_color": ["#3B8ED0", "#1F6AA5"],
    "button_color": ["#36719F", "#144870"],
    "button_hover_color": ["#27577D", "#203A4F"],
    "text_color": ["#DCE4EE", "#DCE4EE"],
    "text_color_disabled": ["gray74", "gray60"]
  },
  "CTkComboBox": {
    "corner_radius": 6,
    "border_width": 1,
    "fg_color": ["#F9F9FA", "#343638"],
    "border_color": ["#f2f2f2", "#303030"],
    "button_color": ["#f2f2f2", "#565B5E"],
    "button_hover_color": ["#f2f2f2", "#565B5E"],
    "text_color": ["gray10", "#ffffff"],
    "text_color_disabled": ["gray50", "gray45"]
  },
  "CTkScrollbar": {
    "corner_radius": 1000,
    "border_spacing": 4,
    "fg_color": "transparent",
    "button_color": ["gray55", "gray41"],
    "button_hover_color": ["gray40", "gray53"]
  },
  "CTkSegmentedButton": {
    "corner_radius": 6,
    "border_width": 2,
    "fg_color": ["#979DA2", "gray29"],
    "selected_color": ["#3B8ED0", "#1F6AA5"],
    "selected_hover_color": ["#36719F", "#144870"],
    "unselected_color": ["#979DA2", "gray29"],
    "unselected_hover_color": ["gray70", "gray41"],
    "text_color": ["#DCE4EE", "#DCE4EE"],
    "text_color_disabled": ["gray74", "gray60"]
  },
  "CTkTextbox": {
    "corner_radius": 6,
    "border_width": 0,
    "fg_color": ["#F9F9FA", "#1D1E1E"],
    "border_color": ["#979DA2", "#565B5E"],
    "text_color":["gray10", "#DCE4EE"],
    "scrollbar_button_color": ["gray55", "gray41"],
    "scrollbar_button_hover_color": ["gray40", "gray53"]
  },
  "CTkScrollableFrame": {
    "label_fg_color": ["gray78", "gray23"]
  },
  "DropdownMenu": {
    "fg_color": ["gray90", "#1c1c1c"],
    "hover_color": ["gray75", "#313131"],
    "text_color": ["gray10", "#ffffff"]
  },
  "CTkFont": {
    "macOS": {
      "family": "SF Display",
      "size": 13,
      "weight": "normal"
    },
    "Windows": {
      "family": "Segoe UI",
      "size": 13,
      "weight": "normal"
    },
    "Linux": {
      "family": "Roboto",
      "size": 13,
      "weight": "normal"
    }
  }
}
"""


import os.path


fluent_path = os.path.abspath(os.path.dirname(__file__)).replace("\\", "/") + "/Fluent.json"


def fluent_theme():
    from tempfile import mkstemp
    from customtkinter import set_default_color_theme
    _, __temp = mkstemp(suffix=".json")
    with open(__temp, "w") as __temp_file:
        __temp_file.write(fluent_json)
    return __temp


def use_fluent_theme():
    from customtkinter import set_default_color_theme
    try:
        set_default_color_theme(fluent_path)
    except FileNotFoundError:
        set_default_color_theme(fluent_theme())
